16.15. cdist-type__cdist(7) — cdist 6.9.8 documentation

# 16.15. cdist-type__cdist(7)

## 16.15.1. NAME

cdist-type__cdist - Manage cdist installations

## 16.15.2. DESCRIPTION

This cdist type allows you to easily setup cdist on another box, to allow the other box to configure systems.

This type is NOT required by target hosts. It is only helpful to build FROM which you configure other hosts.

This type will use git to clone

## 16.15.3. REQUIRED PARAMETERS

## 16.15.4. OPTIONAL PARAMETERS

username

  Select the user to create for the cdist installation. Defaults to "cdist".

source

  Select the source from which to clone cdist from. Defaults to "git@code.ungleich.ch:ungleich-public/cdist.git".

branch

  Select the branch to checkout from. Defaults to "master".

## 16.15.5. EXAMPLES

    # Install cdist for user cdist in her home as subfolder cdist
    __cdist /home/cdist/cdist

    # Use alternative source
    __cdist --source "git@code.ungleich.ch:ungleich-public/cdist.git" /home/cdist/cdist

## 16.15.6. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 16.15.7. COPYING

Copyright (C) 2013 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.